#
# if you remove the qct package without purging it, this conffile
# will be kept and mercurial will try to load the (removed) qct extension
# so it will emit a warning
#
# Two fix are possible in this case:
# 1: purging the qct package (with "apt-get remove --purge qct" for example)
# 2: commenting the line requesting the extension below
[extensions]
hgext.qct =
